@@ -24,8 +24,8 @@ pref("browser.search.param.yahoo-fr", "linuxmint");
 
 // Set the UserAgent
 pref("general.useragent.vendor", "Linux Mint");
-pref("general.useragent.vendorSub", "17.3");
-pref("general.useragent.vendorComment", "Rosa");
+pref("general.useragent.vendorSub", "18");
+pref("general.useragent.vendorComment", "Sarah");
 
 // Default search engine
 pref("browser.search.searchEnginesURL", "http://www.linuxmint.com/searchengines/");
@@ -33,9 +33,6 @@ pref("browser.search.searchEnginesURL", "http://www.linuxmint.com/searchengines/
 // Activate the backspace key for browsing back
 pref("browser.backspace_action", 0);
 
-// Disable ipv6
-pref("network.dns.disableIPv6", true);
-
 // Ignore Mozilla release notes startup pages
 pref("browser.startup.homepage_override.mstone", "ignore");
 
@@ -134,3 +131,41 @@ pref("intl.hyphenation-alias.uk", "uk-ua");
 pref("intl.hyphenation-alias.uk-*", "uk-ua");
 pref("intl.hyphenation-alias.zu", "zu-za");
 pref("intl.hyphenation-alias.zu-*", "zu-za");
+
+// Disable Telemetry
+pref("toolkit.telemetry.unified", false);
+pref("toolkit.telemetry.archive.enabled", false);
+pref("toolkit.telemetry.enabled", false);
+pref("toolkit.telemetry.unifiedIsOptIn", false);
+pref("toolkit.telemetry.server", "data:,");
+pref("toolkit.telemetry.newProfilePing.enabled", false);
+pref("toolkit.telemetry.shutdownPingSender.enabled", false);
+pref("toolkit.telemetry.updatePing.enabled", false);
+pref("toolkit.telemetry.bhrPing.enabled", false);
+pref("toolkit.telemetry.firstShutdownPing.enabled", false);
+pref("toolkit.telemetry.coverage.opt-out", true);
+pref("toolkit.coverage.opt-out", true);
+pref("toolkit.coverage.endpoint.base", "");
+pref("datareporting.policy.dataSubmissionEnabled", false);
+pref("datareporting.healthreport.uploadEnabled", false);
+pref("app.shield.optoutstudies.enabled", false);
+pref("browser.discovery.enabled", false);
+pref("breakpad.reportURL", "");
+pref("browser.tabs.crashReporting.sendReport", false);
+pref("browser.crashReports.unsubmittedCheck.enabled", false);
+pref("browser.crashReports.unsubmittedCheck.autoSubmit2", false);
+
+// Disable welcome pages
+pref("startup.homepage_welcome_url", "");
+pref("startup.homepage_welcome_url.additional", "");
+pref("startup.homepage_override_url", ""); // what's new page afer update
+pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.addons", false);
+pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.features", false);
+pref("browser.newtabpage.activity-stream.feeds.snippets", false);
+
+// Remove sync account from toolbar
+pref("identity.fxaccounts.toolbar.enabled", false); // Firefox Accounts & Sync [FF60+] [RESTART]
+pref("identity.fxaccounts.toolbar.accessed", true); // Firefox Accounts & Sync [FF60+] [RESTART]
+
+// Disable modern search config
+pref("browser.search.modernConfig", false);
